==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/files_sharing/l10n/de_DE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Mit Ihnen geteilt",
    "Shared with others" : "Von Ihnen geteilt",
    "Shared by link" : "Geteilt über einen Link",
    "Nothing shared with you yet" : "Bis jetzt wurde nichts mit Ihnen geteilt",
    "Files and folders others share with you will show up here" : "Mit Ihnen geteilte Dateien und Ordner anderer werden hier erscheinen",
    "Nothing shared yet" : "Noch nichts geteilt",
    "Files and folders you share will show up here" : "Dateien und Ordner, die Sie teilen, werden hier erscheinen",
    "No shared links" : "Keine geteilten Links",
    "Files and folders you share by link will show up here" : "Dateien und Ordner, die Sie per Link teilen, werden hier erscheinen",
    "You can upload into this folder" : "Sie können in diesen Ordner hochladen",
    "No compatible server found at {remote}" : "Keinen kompatiblen Server unter {remote} gefunden",
    "Invalid server URL" : "Falsche Server-URL",
    "Failed to add the public link to your Nextcloud" : "Fehler beim Hinzufügen des öffentlichen Links zu Ihrer Nextcloud",
    "Share" : "Teilen",
    "No expiration date set" : "Kein Ablaufdatum gesetzt",
    "Shared by" : "Geteilt von",
    "Sharing" : "Teilen",
    "File shares" : "Dateifreigaben",
    "Downloaded via public link" : "Über den öffentlichen Link heruntergeladen",
    "Downloaded by %1$s" : "Heruntergeladen von %1$s",
    "Downloaded by {email}" : "Heruntergeladen von {email}",
    "%1$s downloaded via public link" : "%1$s heruntergeladen mittels öffentlichen Link",
    "{file} downloaded via public link" : "{file} heruntergeladen mittels öffentlichen Link",
    "%1$s downloaded %2$s" : "%1$s hat %2$s heruntergeladen",
    "{email} downloaded {file}" : "{email} hat {file} heruntergeladen",
    "Shared with group %1$s" : "Geteilt mit der Gruppe %1$s",
    "Shared with group {group}" : "Geteilt mit der Gruppe {group}",
    "Removed share for group %1$s" : "Freigabe für die Gruppe %1$s entfernt",
    "Removed share for group {group}" : "Freigabe für die Gruppe {group} entfernt",
    "%2$s shared with group %1$s" : "%2$s geteilt mit der Gruppe %1$s",
    "{actor} shared with group {group}" : "{actor} geteilt mit der Gruppe {group}",
    "%2$s removed share for group %1$s" : "%2$s hat die Freigabe für die Gruppe %1$s entfernt",
    "{actor} removed share for group {group}" : "{actor} hat die Freigabe für die Gruppe {group} entfernt",
    "You shared %1$s with group %2$s" : "Sie haben %1$s mit der Gruppe %2$s geteilt",
    "You shared {file} with group {group}" : "Sie haben {file} mit der Gruppe {group} geteilt",
    "You removed group %2$s from %1$s" : "Sie haben die Gruppe %2$s von %1$s entfernt",
    "You removed group {group} from {file}" : "Sie haben die Gruppe {group} von {file} entfernt",
    "%3$s shared %1$s with group %2$s" : "%3$s hat %1$s mit der Gruppe %2$s geteilt",
    "{actor} shared {file} with group {group}" : "{actor} hat {file} mit der Gruppe {group} geteilt",
    "%3$s removed group %2$s from %1$s" : "%3$s hat die Gruppe %2$s von %1$s entfernt",
    "{actor} removed group {group} from {file}" : "{actor} hat die Gruppe {group} von {file} entfernt",
    "Shared as public link" : "Als öffentlichen Link geteilt",
    "Removed public link" : "Öffentlichen Link entfernt",
    "%1$s shared as public link" : "%1$s hat einen öffentlichen Link geteilt",
    "{actor} shared as public link" : "{actor} hat einen öffentlichen Link geteilt",
    "%1$s removed public link" : "%1$s hat einen öffentlichen Link entfernt",
    "{actor} removed public link" : "{actor} hat einen öffentlichen Link entfernt",
    "You shared %1$s as public link" : "Sie haben %1$s über einen öffentlichen Link geteilt",
    "You shared {file} as public link" : "Sie haben {file} über einen öffentlichen Link geteilt",
    "You removed public link for %1$s" : "Sie haben die öffentliche Freigabe für %1$s entfernt",
    "You removed public link for {file}" : "Sie haben die öffentliche Freigabe für {file} entfernt",
    "%2$s shared %1$s as public link" : "%2$s hat %1$s über einen öffentlichen Link geteilt",
    "{actor} shared {file} as public link" : "{actor} hat {file} über einen öffentlichen Link geteilt",
    "%2$s removed public link for %1$s" : "%2$s hat den öffentlichen Link für %1$s entfernt",
    "{actor} removed public link for {file}" : "{actor} hat einen öffentlichen Link {file} entfernt",
    "%1$s accepted the remote share" : "%1$s hat die Remotefreigabe akzeptiert",
    "{user} accepted the remote share" : "{user} hat die Remotefreigabe akzeptiert",
    "%1$s declined the remote share" : "%1$s hat die Remotefreigabe abgelehnt",
    "{user} declined the remote share" : "{user} hat die Remotefreigabe abgelehnt",
    "You received a new remote share %1$s from %2$s" : "Du hast eine neue Remotefreigabe %1$s von %2$s erhalten",
    "You received a new remote share {file} from {user}" : "Du hast eine neue Remotefreigabe {file} von {user} erhalten",
    "%2$s accepted the remote share of %1$s" : "%2$s hat die Remotefreigabe von %1$s akzeptiert",
    "{user} accepted the remote share of {file}" : "{user} hat die Remotefreigabe von {file} akzeptiert",
    "%2$s declined the remote share of %1$s" : "%2$s hat die Remotefreigabe von %1$s abgelehnt",
    "{user} declined the remote share of {file}" : "{user} hat die Remotefreigabe von {file} abgelehnt",
    "%2$s unshared %1$s from you" : "%2$s teilt %1$s nicht mehr mit Ihnen",
    "{user} unshared {file} from you" : "{user} teilt {file} nicht mehr mit Ihnen",
    "Shared with %1$s" : "Geteilt mit %1$s",
    "Shared with {user}" : "Geteilt mit {user}",
    "Removed share for %1$s" : "Freigabe für %1$s entfernt",
    "Removed share for {user}" : "Freigabe für {user} entfernt",
    "%2$s shared with %1$s" : "%2$s hat mit %1$s geteilt",
    "{actor} shared with {user}" : "{actor} hat mit {user} geteilt",
    "%2$s removed share for %1$s" : "%2$s hat die Freigabe für %1$s entfernt",
    "{actor} removed share for {user}" : "{actor} hat die Freigabe für {user} entfernt",
    "Shared by %1$s" : "Geteilt von %1$s",
    "Shared by {actor}" : "Geteilt von {actor}",
    "%1$s removed share" : "%1$s hat die Freigabe entfernt",
    "{actor} removed share" : "{actor} hat die Freigabe entfernt",
    "You shared %1$s with %2$s" : "Sie haben %1$s mit %2$s geteilt",
    "You shared {file} with {user}" : "Du hast {file} mit {user} geteilt",
    "You removed %2$s from %1$s" : "Sie haben die %2$s von %1$s entfernt",
    "You removed {user} from {file}" : "Sie haben die {user} von {file} entfernt",
    "%3$s shared %1$s with %2$s" : "%3$s geteilt %1$s mit %2$s",
    "{actor} removed {user} from {file}" : "{actor} hat {user} von {file} entfernt",
    "%3$s removed %2$s from %1$s" : "%3$s hat %2$s von %1$s entfernt",
    "%2$s shared %1$s with you" : "%2$s hat %1$s mit Ihnen geteilt",
    "{actor} shared {file} with you" : "{actor} hat {file} mit Ihnen geteilt",
    "%2$s removed you from %1$s" : "Sie wurden durch %2$s von %1$s entfernt",
    "{actor} removed you from {file}" : "Sie wurden durch {actor} von {file} entfernt",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Eine Datei oder ein Ordner der per E-Mail oder öffentlich geteilt ist wurde <strong>heruntergeladen</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Eine Datei oder ein Ordner wurde von <strong>einem anderen Server</strong> geteilt",
    "A file or folder has been <strong>shared</strong>" : "Eine Datei oder ein Ordner wurde <strong>geteilt</strong>",
    "Wrong share ID, share doesn't exist" : "Fehlerhafte Freigabe-ID, Freigabe existiert nicht",
    "could not delete share" : "Freigabe konnte nicht gelöscht werden",
    "Could not delete share" : "Freigabe konnte nicht gelöscht werden",
    "Please specify a file or folder path" : "Bitte geben Sie eine Datei oder Ordner an",
    "Wrong path, file/folder doesn't exist" : "Falscher Pfad, Datei/Verzeichnis existiert nicht",
    "Could not create share" : "Freigabe konnte nicht erstellt werden",
    "invalid permissions" : "Ungültige Berechtigung",
    "Please specify a valid user" : "Bitte geben Sie einen gültigen Nutzer an",
    "Group sharing is disabled by the administrator" : "Die Gruppenfreigabe ist durch den Administrator deaktiviert",
    "Please specify a valid group" : "Bitte geben Sie eine gültige Gruppe an",
    "Public link sharing is disabled by the administrator" : "Die öffentliche Freigabe von Links ist durch den Administrator deaktiviert",
    "Public upload disabled by the administrator" : "Das öffentliche Hochladen ist durch den Administrator deaktiviert",
    "Public upload is only possible for publicly shared folders" : "Das öffentliche Hochladen ist nur für öffentlich freigegebene Ordner erlaubt",
    "Invalid date, date format must be YYYY-MM-DD" : "Ungültiges Datum, das Datumsformat muss JJJJ-MM-TT sein",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Freigabe von %s fehlgeschlagen, da das Backend die Freigabe vom Typ %s nicht erlaubt.",
    "Unknown share type" : "Unbekannter Freigabetyp",
    "Not a directory" : "Kein Verzeichnis",
    "Could not lock path" : "Pfad konnte nicht gesperrt werden",
    "Wrong or no update parameter given" : "Falscher oder kein Updateparameter wurde übergeben",
    "Can't change permissions for public share links" : "Berechtigungen für öffentlich freigegebene Links konnten nicht geändert werden",
    "Cannot increase permissions" : "Berechtigungen können nicht erhöht werden",
    "%s is publicly shared" : "%s ist öffentlich geteilt",
    "Share API is disabled" : "Teilen-API ist deaktivert",
    "This share is password-protected" : "Diese Freigabe ist durch ein Passwort geschützt",
    "The password is wrong. Try again." : "Das Passwort ist falsch. Bitte versuchen Sie es erneut.",
    "Password" : "Passwort",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Name" : "Name",
    "Share time" : "Freigabezeitpunkt",
    "Expiration date" : "Ablaufdatum",
    "Sorry, this link doesn’t seem to work anymore." : "Entschuldigung, dieser Link scheint nicht mehr zu funktionieren.",
    "Reasons might be:" : "Gründe könnten sein:",
    "the item was removed" : "Das Element wurde entfernt",
    "the link expired" : "Der Link ist abgelaufen",
    "sharing is disabled" : "Teilen ist deaktiviert",
    "For more info, please ask the person who sent this link." : "Um nähere Informationen zu erhalten, wenden Sie sich bitte an die Person, die Ihnen diesen Link geschickt hat.",
    "Add to your Nextcloud" : "Zu Ihrer Nextcloud hinzufügen",
    "Download" : "Herunterladen",
    "Download %s" : "Download %s",
    "Direct link" : "Direkter Link",
    "Upload files to %s" : "Dateien für %s hochladen",
    "Select or drop files" : "Dateien auswählen oder hierher ziehen",
    "Uploading files…" : "Dateien werden hochgeladen...",
    "Uploaded files:" : "Hochgeladene Dateien: ",
    "A public shared file or folder was <strong>downloaded</strong>" : "Eine öffentliche geteilte Datei oder ein öffentlicher geteilter Ordner wurde <strong>heruntergeladen</strong>",
    "You received a new remote share %2$s from %1$s" : "Sie haben eine neue Remotefreigabe %2$s von %1$s erhalten",
    "You received a new remote share from %s" : "Sie haben eine neue Remotefreigabe von %s erhalten",
    "%1$s accepted remote share %2$s" : "%1$s hat die Remotefreigabe von %2$s akzeptiert",
    "%1$s declined remote share %2$s" : "%1$s hat die Remotefreigabe von %2$s abgelehnt",
    "%1$s unshared %2$s from you" : "%1$s hat die Freigabe von %2$s für Sie entfernt",
    "Public shared folder %1$s was downloaded" : "Der öffentliche geteilte Ordner %1$s wurde heruntergeladen",
    "Public shared file %1$s was downloaded" : "Die öffentliche geteilte Datei %1$s wurde heruntergeladen",
    "%2$s shared %1$s with %3$s" : "%2$s hat %1$s mit %3$s geteilt",
    "You removed the share of %2$s for %1$s" : "Sie haben die Freigabe von %2$s für %1$s entfernt",
    "%2$s removed the share of %3$s for %1$s" : "%2$s hat die Freigabe von %3$s für %1$s entfernt",
    "%2$s shared %1$s with group %3$s" : "%2$s hat %1$s mit der Gruppe %3$s geteilt",
    "You removed the share of group %2$s for %1$s" : "Sie haben die Freigabe der Gruppe %2$s für %1$s entfernt",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s hat die Freigabe der Gruppe %3$s für %1$s entfernt",
    "%2$s shared %1$s via link" : "%2$s hat %1$s über einen Link geteilt",
    "You shared %1$s via link" : "Sie haben %1$s über einen Link geteilt",
    "You removed the public link for %1$s" : "Sie haben die Freigabe als Link für %1$s entfernt",
    "%2$s removed the public link for %1$s" : "%2$s hat den öffentlichen Link für %1$s entfernt",
    "Your public link for %1$s expired" : "Ihre Freigabe als Link für %1$s ist abgelaufen",
    "The public link of %2$s for %1$s expired" : "Die Freigabe als Link von %2$s für %1$s ist abgelaufen",
    "%2$s removed the share for %1$s" : "%2$s hat die Freigabe für %1$s entfernt",
    "Shared with %2$s" : "Geteilt mit %2$s",
    "Shared with %3$s by %2$s" : "Geteilt mit %3$s von %2$s",
    "Removed share for %2$s" : "Freigabe für %2$s entfernt",
    "%2$s removed share for %3$s" : "%2$s hat die Freigabe für %3$s entfernt",
    "Shared with group %2$s" : "Geteilt mit der Gruppe %2$s",
    "Shared with group %3$s by %2$s" : "Geteilt mit der Gruppe %3$s von %2$s",
    "Removed share of group %2$s" : "Freigabe für Gruppe %2$s entfernt",
    "%2$s removed share of group %3$s" : "%2$s hat die Freigabe für Gruppe %3$s entfernt",
    "Shared via link by %2$s" : "Geteilt durch einen Link von %2$s",
    "Shared via public link" : "Durch einen öffentlichen Link geteilt",
    "%2$s removed public link" : "%2$s hat die Freigabe als Link entfernt",
    "Public link expired" : "öffentlicher Link ist abgelaufen",
    "Public link of %2$s expired" : "Öffentlicher Link von %2$s ist abgelaufen",
    "Shared by %2$s" : "Geteilt von %2$s",
    "Shares" : "Geteiltes",
    "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
    "The mountpoint name contains invalid characters." : "Der Name des Einhängepunktes enthält ungültige Zeichen.",
    "Not allowed to create a federated share with the same user server" : "Das Erstellen einer Federated Cloud Freigabe mit dem gleichen Benutzer-Server ist nicht erlaubt",
    "Invalid or untrusted SSL certificate" : "Ungültiges oder nicht vertrauenswürdiges SSL-Zertifikat",
    "Could not authenticate to remote share, password might be wrong" : "Die Authentifizierung an der entfernten Freigabe konnte nicht erfolgen, das Passwort könnte falsch sein",
    "Storage not valid" : "Speicher ungültig",
    "Couldn't add remote share" : "Entfernte Freigabe kann nicht hinzugefügt werden",
    "Federated sharing" : "Federated-Sharing",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Möchten Sie die entfernte Freigabe {name} von {owner}@{remote} hinzufügen? ",
    "Remote share" : "Entfernte Freigabe",
    "Remote share password" : "Passwort für die entfernte Freigabe",
    "Cancel" : "Abbrechen",
    "Add remote share" : "Entfernte Freigabe hinzufügen",
    "No ownCloud installation (7 or higher) found at {remote}" : "Keine OwnCloud-Installation (7 oder höher) auf {remote} gefunden",
    "Invalid ownCloud url" : "Ungültige Nextcloud-Adresse",
    "You received \"/%2$s\" as a remote share from %1$s" : "Sie haben \"/%2$s\" als Remotefreigabe von %1$s erhalten",
    "Accept" : "Akzeptieren",
    "Decline" : "Ablehnen",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Teilen Sie mit mir über meine #ownCloud Federated-Cloud-ID, siehe %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Teilen Sie mit mir über meine #ownCloud Federated-Cloud-ID",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "Open documentation" : "Dokumentation öffnen",
    "Allow users on this server to send shares to other servers" : "Gestatten Sie Nutzern dieses Servers Freigaben von anderen Servern zu erhalten",
    "Allow users on this server to receive shares from other servers" : "Erlauben Sie Nutzern dieses Servers Freigaben von anderen Servern zu erhalten",
    "Federated Cloud" : "Federated-Cloud",
    "Your Federated Cloud ID:" : "Deine Federated-Cloud-ID:",
    "Share it:" : "Teilen:",
    "Add to your website" : "Zu Ihrer Web-Seite hinzufügen",
    "Share with me via Nextcloud" : "Teilen Sie mit mir über Nextcloud ",
    "HTML Code:" : "HTML-Code:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/files_sharing/l10n/de_DE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Mit Ihnen geteilt",
    "Shared with others" : "Von Ihnen geteilt",
    "Shared by link" : "Geteilt über einen Link",
    "Nothing shared with you yet" : "Bis jetzt wurde nichts mit Ihnen geteilt",
    "Files and folders others share with you will show up here" : "Mit Ihnen geteilte Dateien und Ordner anderer werden hier erscheinen",
    "Nothing shared yet" : "Noch nichts geteilt",
    "Files and folders you share will show up here" : "Dateien und Ordner, die Sie teilen, werden hier erscheinen",
    "No shared links" : "Keine geteilten Links",
    "Files and folders you share by link will show up here" : "Per Link freigegebene Dateien und Ordner werden hier erscheinen",
    "You can upload into this folder" : "Sie können in diesen Ordner hochladen",
    "No compatible server found at {remote}" : "Keinen kompatiblen Server unter {remote} gefunden",
    "Invalid server URL" : "Falsche Server-URL",
    "Failed to add the public link to your Nextcloud" : "Fehler beim Hinzufügen des öffentlichen Links zu Ihrer Nextcloud",
    "Share" : "Teilen",
    "No expiration date set" : "Kein Ablaufdatum gesetzt",
    "Shared by" : "Geteilt von",
    "Sharing" : "Teilen",
    "File shares" : "Dateifreigaben",
    "Downloaded via public link" : "Über den öffentlichen Link heruntergeladen",
    "Downloaded by {email}" : "Heruntergeladen von {email}",
    "{file} downloaded via public link" : "{file} heruntergeladen mittels öffentlichen Link",
    "{email} downloaded {file}" : "{email} hat {file} heruntergeladen",
    "Shared with group {group}" : "Geteilt mit der Gruppe {group}",
    "Removed share for group {group}" : "Freigabe für die Gruppe {group} entfernt",
    "{actor} shared with group {group}" : "{actor} geteilt mit der Gruppe {group}",
    "{actor} removed share for group {group}" : "{actor} hat die Freigabe für die Gruppe {group} entfernt",
    "You shared {file} with group {group}" : "Sie haben {file} mit der Gruppe {group} geteilt",
    "You removed group {group} from {file}" : "Sie haben die Gruppe {group} von {file} entfernt",
    "{actor} shared {file} with group {group}" : "{actor} hat {file} mit der Gruppe {group} geteilt",
    "{actor} removed group {group} from {file}" : "{actor} hat die Gruppe {group} von {file} entfernt",
    "Shared as public link" : "Als öffentlichen Link geteilt",
    "Removed public link" : "Öffentlichen Link entfernt",
    "Public link expired" : "Öffentlicher Link ist abgelaufen",
    "{actor} shared as public link" : "{actor} hat einen öffentlichen Link geteilt",
    "{actor} removed public link" : "{actor} hat einen öffentlichen Link entfernt",
    "Public link of {actor} expired" : "Öffentlicher Link von {actor} ist abgelaufen",
    "You shared {file} as public link" : "Sie haben {file} über einen öffentlichen Link geteilt",
    "You removed public link for {file}" : "Sie haben die öffentliche Freigabe für {file} entfernt",
    "Public link expired for {file}" : "Öffentlicher Link für {file} ist abgelaufen",
    "{actor} shared {file} as public link" : "{actor} hat {file} über einen öffentlichen Link geteilt",
    "{actor} removed public link for {file}" : "{actor} hat einen öffentlichen Link {file} entfernt",
    "Public link of {actor} for {file} expired" : "Öffentlicher Link von {actor} für {file} ist abgelaufen",
    "{user} accepted the remote share" : "{user} hat die Remotefreigabe akzeptiert",
    "{user} declined the remote share" : "{user} hat die Remotefreigabe abgelehnt",
    "You received a new remote share {file} from {user}" : "Sie haben eine neue Remotefreigabe {file} von {user} erhalten",
    "{user} accepted the remote share of {file}" : "{user} hat die Remotefreigabe von {file} akzeptiert",
    "{user} declined the remote share of {file}" : "{user} hat die Remotefreigabe von {file} abgelehnt",
    "{user} unshared {file} from you" : "{user} hat die Freigabe für {file} entfernt",
    "Shared with {user}" : "Geteilt mit {user}",
    "Removed share for {user}" : "Freigabe für {user} entfernt",
    "{actor} shared with {user}" : "{actor} hat mit {user} geteilt",
    "{actor} removed share for {user}" : "{actor} hat die Freigabe für {user} entfernt",
    "Shared by {actor}" : "Geteilt von {actor}",
    "{actor} removed share" : "{actor} hat die Freigabe entfernt",
    "You shared {file} with {user}" : "Sie haben {file} mit {user} geteilt",
    "You removed {user} from {file}" : "Sie haben {user} von {file} entfernt",
    "{actor} shared {file} with {user}" : "{actor} hat {file} mit {user} geteilt",
    "{actor} removed {user} from {file}" : "{actor} hat {user} von {file} entfernt",
    "{actor} shared {file} with you" : "{actor} hat {file} mit Ihnen geteilt",
    "{actor} removed you from {file}" : "Sie wurden durch {actor} von {file} entfernt",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Öffentlich oder per E-Mail geteilte Datei / Ordner wurde <strong>heruntergeladen</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Eine Datei oder ein Ordner wurde von <strong>einem anderen Server</strong> geteilt",
    "A file or folder has been <strong>shared</strong>" : "Eine Datei oder ein Ordner wurde <strong>geteilt</strong>",
    "Wrong share ID, share doesn't exist" : "Fehlerhafte Freigabe-ID, Freigabe existiert nicht",
    "could not delete share" : "Freigabe konnte nicht gelöscht werden",
    "Could not delete share" : "Freigabe konnte nicht gelöscht werden",
    "Please specify a file or folder path" : "Bitte Datei oder Ordner-Pfad eingeben",
    "Wrong path, file/folder doesn't exist" : "Falscher Pfad, Datei/Ordner existiert nicht",
    "Could not create share" : "Freigabe konnte nicht erstellt werden",
    "invalid permissions" : "Ungültige Berechtigung",
    "Please specify a valid user" : "Bitte geben Sie einen gültigen Benutzer an",
    "Group sharing is disabled by the administrator" : "Die Gruppenfreigabe ist durch den Administrator deaktiviert",
    "Please specify a valid group" : "Bitte geben Sie eine gültige Gruppe an",
    "Public link sharing is disabled by the administrator" : "Die öffentliche Freigabe von Links ist durch den Administrator deaktiviert",
    "Public upload disabled by the administrator" : "Das öffentliche Hochladen ist durch den Administrator deaktiviert",
    "Public upload is only possible for publicly shared folders" : "Das öffentliche Hochladen ist nur für öffentlich freigegebene Ordner erlaubt",
    "Invalid date, date format must be YYYY-MM-DD" : "Ungültiges Datum, das Datumsformat muss JJJJ-MM-TT sein",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Freigabe von %s fehlgeschlagen, da das Backend die Freigabe vom Typ %s nicht erlaubt.",
    "You cannot share to a Circle if the app is not enabled" : "Sie können nichts mit einem Kreis teilen, wenn die App nicht aktiviert ist",
    "Please specify a valid circle" : "Bitte einen gültigen Kreis angeben",
    "Unknown share type" : "Unbekannter Freigabetyp",
    "Not a directory" : "Kein Verzeichnis",
    "Could not lock path" : "Pfad konnte nicht gesperrt werden",
    "Wrong or no update parameter given" : "Es wurde ein falscher oder kein Updateparameter angegeben",
    "Can't change permissions for public share links" : "Berechtigungen für öffentlich freigegebene Links konnten nicht geändert werden",
    "Cannot increase permissions" : "Berechtigungen können nicht erhöht werden",
    "Share API is disabled" : "Teilen-API ist deaktivert",
    "This share is password-protected" : "Freigabe ist passwortgeschützt",
    "The password is wrong. Try again." : "Das Passwort ist falsch. Bitte versuchen Sie es erneut.",
    "Password" : "Passwort",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Name" : "Name",
    "Share time" : "Freigabezeitpunkt",
    "Expiration date" : "Ablaufdatum",
    "Sorry, this link doesn’t seem to work anymore." : "Entschuldigung, dieser Link scheint nicht mehr zu funktionieren.",
    "Reasons might be:" : "Gründe könnten sein:",
    "the item was removed" : "Das Element wurde entfernt",
    "the link expired" : "Der Link ist abgelaufen",
    "sharing is disabled" : "Teilen ist deaktiviert",
    "For more info, please ask the person who sent this link." : "Um nähere Informationen zu erhalten, wenden Sie sich bitte an die Person, die Ihnen diesen Link geschickt hat.",
    "shared by %s" : "von %s geteilt",
    "Download" : "Herunterladen",
    "Direct link" : "Direkter Link",
    "Add to your Nextcloud" : "Zu Ihrer Nextcloud hinzufügen",
    "Download %s" : "Download %s",
    "Upload files to %s" : "Dateien für %s hochladen",
    "Select or drop files" : "Dateien auswählen oder hierher ziehen",
    "Uploading files…" : "Dateien werden hochgeladen…",
    "Uploaded files:" : "Hochgeladene Dateien: ",
    "%s is publicly shared" : "%s ist öffentlich geteilt"
},
"nplurals=2; plural=(n != 1);");
